@@ -82,12 +82,14 @@ class Travis2Docker(object):
         self.variables_sh_data = {}
         if deployv:
             self.variables_sh_data = {var.lower(): value for _, _, var, value in self.re_export.findall(os_kwargs['variables_sh'])}
-            image = "%(docker_image_repo)s:%(customer)s-%(version)s-latest" % self.variables_sh_data if not image else image
+            image = "%(docker_image_repo)s:%(main_app)s-%(version)s-latest" % self.variables_sh_data if not image else image
             # TODO: Get the image based on the git sha
             build_sh = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'templates', 'build.sh')
             entrypoint_sh = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'templates', 'entrypoint_deployv.sh')
+            docker_helper = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'docker_helper')
             copy_paths.append([build_sh, '/home/odoo/build.sh'])
             copy_paths.append([entrypoint_sh, '/entrypoint.sh'])
+            copy_paths.append([docker_helper, '/home/odoo/build'])
         if image is None:
             image = 'vauxoo/odoo-80-image-shippable-auto'
         if os_kwargs is None:
